contourpy.util
--------------

.. automodule:: contourpy.util

This module consists of utility functions that are used internally for tests and examples.
Please feel free to use them to experiment with ``contourpy``, but you should not use them in
downstream projects as they are liable to change at short notice without a formal deprecation
period.

.. autofunction:: build_config

.. automodule:: contourpy.util.data
   :members:

.. automodule:: contourpy.util.renderer
   :members:

.. automodule:: contourpy.util.bokeh_renderer
   :members:

.. automodule:: contourpy.util.mpl_renderer
   :members: MplRenderer
